<?php
/** 
 * The Google Content Experiments Class
 */
class GCE {

	public function __construct() {
		add_action( 'wp', array( $this, 'setup' ) );
	}
	
	/** 
	 * Function executed at start
	 */
	public function setup() {
		// Don't output Content Experiment code on the homepage when showing posts
		if ( is_home() )
			return;
		
		// Else, continue
		global $post;
		$wpe_gce_active = get_post_meta($post->ID, '_wpe_gce_active', TRUE);
		
		// Add code if Content Experiment is enabled for this post/page
		if( isset($wpe_gce_active) && $wpe_gce_active == '1' ) {
			add_action( 'wp', array( $this, 'prepare_output' ), 0 );
		}
	}

	/** 
	 * Checks how to insert the code
	 */
	public function prepare_output() {
		// Add output_code function to custom hook
		add_action( 'wpe_gce_head', array( $this, 'output_code' ), 0 );
		
		// Check if active theme is in the list
		switch ($this->check_theme()) {
			case 'genesis':
				remove_action( 'genesis_doctype', 'genesis_do_doctype' );
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" <?php language_attributes( 'xhtml' ); ?>>
<head profile="http://gmpg.org/xfn/11">
<?php
				do_action( 'wpe_gce_head' );
?>
<meta http-equiv="Content-Type" content="<?php bloginfo( 'html_type' ); ?>; charset=<?php bloginfo( 'charset' ); ?>" />
<?php
				break;
			default:
				// Theme not supported, insert hook manually
				break;
		}
	}
	
	/** 
	 *  The code to output after the <head> tag
	 */
	public function output_code() {
		global $post;
		$wpe_gce_code = get_post_meta($post->ID, '_wpe_gce_code', TRUE);
		echo $wpe_gce_code.PHP_EOL;;
	}
	
	/**
	 * Check which theme is active
	 */
	public function check_theme() {
		$active_theme = wp_get_theme();
		return $active_theme->{'Template'};
	}

}
	
?>